/*
     File:       DICOM_Toolkit_GraphicImport.h

     Contains:   Escape DICOM Toolkit Graphic Importer Component Interfaces.

     Copyright:  (c)2002-2004 by Escape Information Services, all rights reserved.

     Bugs?       For support or bug reports please send email to support@escape.gr
 
*/
#ifndef __DICOM_TOOLKIT_GRAPHICIMPORT__
#define __DICOM_TOOLKIT_GRAPHICIMPORT__

#ifndef __MACH__
	#ifndef __IMAGECOMPRESSION__
		#include <ImageCompression.h>
	#endif
#else
	#include <Carbon/Carbon.h>
	#include <QuickTime/QuickTime.h>
#endif

#ifndef __DICOM_TOOLKIT_TYPES__
	#include "DICOM_Toolkit_Types.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_IMPORT
#pragma import on
#endif


/*!
    @header DICOM_Toolkit_GraphicImport.h
    @discussion This header includes the declarations of the private functions of the DICOM Graphic Importer component
*/

#pragma export on

/*!
    @function DTkGraphicsImportGetImageDataInfo
    @abstract 		Retrieves information about the pixel data corresponding to the graphics importer
    @discussion Valid values for the selector are those specified in the DTkPixelInfoSelector enumeration.
                The correspondence between selector and type of the return value is given in the following table:
                <DIV align = "CENTER">
                <TABLE border = "1" width="90%">
                    <thead> <TR><TH>Selector                     </TH><TH>Type              </TH></TR></thead>
                            <TR><TD>kDTkSelector_CompressionType </TD><TD>DTkCompressionType</TD></TR>
                            <TR><TD>kDTkSelector_HasOverlaysQuery</TD><TD>Boolean           </TD></TR>
                </TABLE>
                </DIV>
    @param gi       [I] The (DICOM) graphics import component instance
    @param selector [I] Selector which specifies kind of information to be retrieved.
    @param output   [O] Pointer to a returned value appropriate to the selector
    @result Error code
*/
EXTERN_API(ComponentResult) DTkGraphicsImportGetImageDataInfo(
                                                               GraphicsImportComponent gi, 
                                                               DTkGraphicsImportImageDataInfoSelector selector, 
                                                               void * output
                                                             );



/*! 
    @function DTkGraphicsImportGetParserComponentInstance
    @abstract   Returns the parser component instance used internally by the graphics importer.
    @discussion This call improves efficiency of the calling application by allowing it to exploit the parser 
                component instance used internally by the graphics importer. In the general case this component instance
                will have already been initialized and much of the overhead associated with establishing a new 
                connection with a DICOM source will be avoided.
    @param gi        [I] The (DICOM) graphics import component instance
    @param parser_ci [O] Pointer to the parser component intance to be retrieved
    @result Error code
*/
EXTERN_API(ComponentResult)DTkGraphicsImportGetParserComponentInstance(
                                                                        GraphicsImportComponent gi,
                                                                        DTkParserComponentInstance *parser_ci
                                                                      );



/*! 
    @function DTkGraphicsImportOverlayGetCountForFrame
    @abstract  Returns the number of overlays that correspond to the current frame.
    @param gi	        [I] The (DICOM) graphics import component instance.
    @param overlayCount [O] Points to a variable to receive the number of overlays corresponding to the current frame. 
    @result Error code
*/
EXTERN_API(ComponentResult)DTkGraphicsImportGetOverlayCount(
                                                             GraphicsImportComponent gi,
                                                             UInt32 *overlayCount
                                                           );



/*! 
    @function DTkGraphicsImportSetOverlayIndex
    @abstract Sets the current overlay index for the current frame
    @discussion Overlay indexes are one-based. The default overlay index is 1. 
    @param gi	            [I] The (DICOM) graphics import component instance
    @param overlayFileIndex [I] The file based overlay index.
    @result Error code
*/
EXTERN_API(ComponentResult)DTkGraphicsImportSetOverlayIndex(
                                                             GraphicsImportComponent gi,
                                                             UInt32 overlayFileIndex
                                                           );



/*! 
    @function DTkGraphicsImportGetOverlayIndex
    @abstract Retrieves the current overlay index for the current frame
    @discussion Overlay indexes are one-based. The default overlay index is 1. 
    @param gi	            [I] The (DICOM) graphics import component instance.
    @param overlayFileIndex [O]	Points to a variable to receive the overlay index.
    @result Error code
*/
EXTERN_API(ComponentResult)DTkGraphicsImportGetOverlayIndex(
                                                             GraphicsImportComponent gi,
                                                             UInt32* overlayFileIndex
                                                           );



/*! 
    @function DTkGraphicsImportGetOverlayDataOffsetAndSize
    @abstract   Returns the offset and size of the compressed overlay data within an imported DICOM file.
    @discussion This function returns the offset and size of the actual overlay data within the data 
                source for the current overlay. In files in which the overlay data are interlaced with the image data
                the offset and size of the image containing the overlay data are returned.
    
    @param gi	         [I] The (DICOM) graphics import component instance.
    @param overlayOffset [O] A pointer to a value describing the byte offset of the overlay data from the beginning of the data source. 
    @param overlaySize   [O] A pointer to a value describing the size of the overlay data in bytes. 
    @result Error code
*/
EXTERN_API(ComponentResult)DTkGraphicsImportGetOverlayDataOffsetAndSize(
                                                                         GraphicsImportComponent gi,
                                                                         UInt32* overlayOffset,
                                                                         UInt32* overlaySize 
                                                                       );


/*! 
    @function DTkGraphicsImportGetOverlayBounds
    @abstract   Retrieves the bounding rectangle of the overlay
    @param gi     [I] The (DICOM) graphics import component instance.
    @param bounds [O] A pointer to a Rect struct that will be set to the bounds of the overlay rectangle.
    @result Error code
*/
EXTERN_API(ComponentResult)DTkGraphicsImportGetOverlayBounds(
                                                              GraphicsImportComponent gi,
                                                              Rect* bounds
                                                            );


/*! 
    @function DTkGraphicsImportGetOverlayImageDescription
    @abstract   
    @discussion This function returns an ImageDescription structure containing information such as the
                format of the compressed data, its bit depth, natural bounds, and resolution. 
                The caller is responsible for disposing of the returned image description handle. 
    @param gi   [I] The (DICOM) graphics import component instance.
    @param desc [O] Points to a handle to an ImageDescription structure. 
    @param    
    @result Error code
*/
EXTERN_API(ComponentResult)DTkGraphicsImportGetOverlayImageDescription(
                                                                       GraphicsImportComponent gi,
                                                                       ImageDescriptionHandle* desc
                                                                      );


/*! 
    @function DTkGraphicsImportOverlayFrameIndexToID
    @abstract Converts an image based overlay index to a file based overlay ID
    @discussion The fundamental numbering of overlays is file based. Use this function to convert 
                image based overlay indices to file based ones. IDs have a one to one corresondence to overlays,
                whereas the same overlay may be referenced by a different frame index for different frames. The 
                frame index refers to the current frame.
    @param gi                [I] The (DICOM) graphics import component instance.
    @param overlayFrameIndex [I] The frame based overlay index.
    @param overlayID         [O] Points to a variable to receive the overlayID.
    @result Error code
*/
EXTERN_API(ComponentResult)DTkGraphicsImportOverlayFrameIndexToID(
                                                                  GraphicsImportComponent gi,
                                                                  UInt32 overlayFrameIndex,
                                                                  UInt32 *overlayID
                                                                 );


/*! 
    @function DTkGraphicsImportOverlayIDToFrameIndex
    @abstract Converts file based overlay ID to a an image based overlay index
    @discussion The fundamental numbering of overlays is file based. Use this function to convert 
                file based overlay indices to image based ones. IDs have a one to one corresondence to overlays,
                whereas the same overlay may be referenced by a different frame index for different frames. The 
                frame index refers to the current frame.
    @param gi                [I] The (DICOM) graphics import component instance.
    @param overlayID         [I] The file based the overlayID.
    @param overlayFrameIndex [O] Points to a variable to receive the frame based overlay index (for the current image frame).
    @result Error code
*/
EXTERN_API(ComponentResult)DTkGraphicsImportOverlayIDToFrameIndex(
                                                                  GraphicsImportComponent gi,
                                                                  UInt32 overlayID,
                                                                  UInt32 *overlayFrameIndex
                                                                 );
#pragma export off

#ifdef PRAGMA_IMPORT_OFF
#pragma import off
#elif PRAGMA_IMPORT
#pragma import reset
#endif

#ifdef __cplusplus
}
#endif


#endif // __DICOM_TOOLKIT_GRAPHICIMPORT__
